timeseries.Signal
=================

.. currentmodule:: timeseries

.. autoclass:: Signal

   

      .. autosummary::
         :toctree:
      
         Signal.feature
         Signal.feature_match
         Signal.from_pointcloud
         Signal.gap
         Signal.height_measure
         Signal.interval_height
         Signal.iter_features
         Signal.iter_intervals
         Signal.iter_windows_by_index
         Signal.jagged
         Signal.make_pers
         Signal.normalize
         Signal.plot
         Signal.profile
         Signal.sample_near
         Signal.self_similarity
         Signal.smoothen



   

